Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(6360)

Unified Diff: chrome/common/gtk_util.h

Issue 160025: GTK Themes: Theme the bookmark bubble. (And first run bubble). (Closed)
Patch Set: Remove text_color for estade Created 11 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/gtk/info_bubble_gtk.cc ('k') | chrome/common/gtk_util.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/common/gtk_util.h
diff --git a/chrome/common/gtk_util.h b/chrome/common/gtk_util.h
index 4a17c21ccad20a4ee253e8172b4bc199f5443c32..399cb42b094da941c988d85058de7d078f3b8867 100644
--- a/chrome/common/gtk_util.h
+++ b/chrome/common/gtk_util.h
@@ -7,6 +7,7 @@
#include <gtk/gtk.h>
#include <string>
+#include <vector>
#include "base/gfx/point.h"
#include "base/gfx/rect.h"
@@ -50,16 +51,20 @@ const int kContentAreaBorder = 12;
const int kContentAreaSpacing = 18;
// Create a table of labeled controls, using proper spacing and alignment.
// Arguments should be pairs of const char*, GtkWidget*, concluding with a NULL.
// The first argument is a color to force the label text to. It can be NULL to
// get the system default.
// For example:
-// controls = CreateLabeledControlsGroup(&gfx::kGdkBlack,
+// controls = CreateLabeledControlsGroup(NULL, &gfx::kGdkBlack,
// "Name:", title_entry_,
// "Folder:", folder_combobox_,
// NULL);
-GtkWidget* CreateLabeledControlsGroup(const GdkColor* color,
- const char* text, ...);
+GtkWidget* CreateLabeledControlsGroup(
+ std::vector<GtkWidget*>* labels,
+ const char* text, ...);
// Create a GtkBin with |child| as its child widget. This bin will paint a
// border of color |color| with the sizes specified in pixels.
« no previous file with comments | « chrome/browser/gtk/info_bubble_gtk.cc ('k') | chrome/common/gtk_util.cc » ('j') | no next file with comments »
@@ -50,16 +51,20 @@ const int kContentAreaBorder = 12;
const int kContentAreaSpacing = 18;
// Create a table of labeled controls, using proper spacing and alignment.
-// Arguments should be pairs of const char*, GtkWidget*, concluding with a NULL.
-// The first argument is a color to force the label text to. It can be NULL to
-// get the system default.
+// Arguments should be pairs of const char*, GtkWidget*, concluding with a
+// NULL. The first argument is a vector in which to place all labels
+// produced. It can be NULL if you don't need to keep track of the label
+// widgets. The second argument is a color to force the label text to. It can
+// be NULL to get the system default.
+//
// For example:

Powered by Google App Engine
This is Rietveld 408576698